@@ -25,10 +25,10 @@ import (
 	"time"
 
 	"github.com/Jeffail/gabs"
-	monitoringv1 "github.com/coreos/prometheus-operator/pkg/apis/monitoring/v1"
 	"github.com/gogo/protobuf/proto"
 	"github.com/openshift/cluster-monitoring-operator/test/e2e/framework"
 	"github.com/pkg/errors"
+	monitoringv1 "github.com/prometheus-operator/prometheus-operator/pkg/apis/monitoring/v1"
 	appsv1 "k8s.io/api/apps/v1"
 	v1 "k8s.io/api/core/v1"
 	apierrors "k8s.io/apimachinery/pkg/api/errors"
@@ -42,44 +42,6 @@ const (
 )
 
 func TestUserWorkloadMonitoring(t *testing.T) {
-	cm := &v1.ConfigMap{
-		ObjectMeta: metav1.ObjectMeta{
-			Name:      "cluster-monitoring-config",
-			Namespace: f.Ns,
-		},
-		Data: map[string]string{
-			"config.yaml": `techPreviewUserWorkload:
-      enabled: true
-`,
-		},
-	}
-
-	for _, scenario := range []struct {
-		name string
-		f    func(*testing.T)
-	}{
-		{"enable user workload monitoring, assert prometheus rollout", createUserWorkloadAssets(cm)},
-		{"assert thanos ruler deployment", assertThanosRulerDeployment},
-		{"assert metrics for user workload components", assertMetricsForMonitoringComponents},
-		{"create and assert an user application is deployed", deployUserApplication},
-		{"create prometheus and alertmanager in user namespace", createPrometheusAlertmanagerInUserNamespace},
-		{"assert user workload metrics", assertUserWorkloadMetrics},
-		{"assert user workload rules", assertUserWorkloadRules},
-		{"assert tenancy model is enforced for metrics", assertTenancyForMetrics},
-		{"assert tenancy model is enforced for rules", assertTenancyForRules},
-		{"assert prometheus and alertmanager is not deployed in user namespace", assertPrometheusAlertmanagerInUserNamespace},
-		{"assert grpc tls rotation", assertGRPCTLSRotation},
-		{"assert user workload metrics", assertUserWorkloadMetrics},
-		{"assert user workload rules", assertUserWorkloadRules},
-		{"assert assets are deleted when user workload monitoring is disabled", assertDeletedUserWorkloadAssets(cm)},
-	} {
-		if ok := t.Run(scenario.name, scenario.f); !ok {
-			t.Fatalf("scenario %q failed", scenario.name)
-		}
-	}
-}
-
-func TestUserWorkloadMonitoringNewConfig(t *testing.T) {
 	cm := &v1.ConfigMap{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      "cluster-monitoring-config",
@@ -112,9 +74,23 @@ func TestUserWorkloadMonitoringNewConfig(t *testing.T) {
 		name string
 		f    func(*testing.T)
 	}{
+		{"enable user workload monitoring, assert prometheus rollout", createUserWorkloadAssets(cm)},
+		{"assert thanos ruler deployment", assertThanosRulerDeployment},
+		{"assert metrics for user workload components", assertMetricsForMonitoringComponents},
+		{"create and assert an user application is deployed", deployUserApplication},
+		{"create prometheus and alertmanager in user namespace", createPrometheusAlertmanagerInUserNamespace},
+		{"assert user workload metrics", assertUserWorkloadMetrics},
+		{"assert user workload rules", assertUserWorkloadRules},
+		{"assert tenancy model is enforced for metrics", assertTenancyForMetrics},
+		{"assert tenancy model is enforced for rules", assertTenancyForRules},
+		{"assert prometheus and alertmanager is not deployed in user namespace", assertPrometheusAlertmanagerInUserNamespace},
+		{"assert grpc tls rotation", assertGRPCTLSRotation},
+		{"assert user workload metrics", assertUserWorkloadMetrics},
+		{"assert user workload rules", assertUserWorkloadRules},
 		{"enable user workload monitoring, assert prometheus rollout", createUserWorkloadAssets(cm)},
 		{"set VolumeClaimTemplate for prometheus CR, assert that it is created", assertPrometheusVCConfig(uwmCM)},
 		{"assert assets are deleted when user workload monitoring is disabled", assertDeletedUserWorkloadAssets(cm)},
+		{"assert assets are deleted when user workload monitoring is disabled", assertDeletedUserWorkloadAssets(cm)},
 	} {
 		if ok := t.Run(scenario.name, scenario.f); !ok {
 			t.Fatalf("scenario %q failed", scenario.name)
@@ -153,7 +129,7 @@ func assertPrometheusVCConfig(cm *v1.ConfigMap) func(*testing.T) {
 
 }
 
-func TestUserWorkloadMonitoringThanosRulerVolumeClaim(t *testing.T) {
+func TestUserWorkloadMonitoringThanosRulerConfigurations(t *testing.T) {
 	cm := &v1.ConfigMap{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      "cluster-monitoring-config",
@@ -172,6 +148,10 @@ func TestUserWorkloadMonitoringThanosRulerVolumeClaim(t *testing.T) {
 		},
 		Data: map[string]string{
 			"config.yaml": `thanosRuler:
+  resources:
+    requests:
+      cpu: 12m
+      memory: 13Mi
   volumeClaimTemplate:
     spec:
       storageClassName: gp2
@@ -187,7 +167,8 @@ func TestUserWorkloadMonitoringThanosRulerVolumeClaim(t *testing.T) {
 		f    func(*testing.T)
 	}{
 		{"enable user workload monitoring, assert prometheus rollout", createUserWorkloadAssets(cm)},
-		{"set VolumeClaimTemplate for thanosRuler CR, assert that it is created", assertThanosRulerVCConfig(uwmCM)},
+		{"set configurations for thanosRuler CR, assert that PVC is created", assertThanosRulerVCConfig(uwmCM)},
+		{"assert that resource requests are created", assertThanosRulerResourcesConfigured("12m", "13Mi")},
 		{"assert assets are deleted when user workload monitoring is disabled", assertDeletedUserWorkloadAssets(cm)},
 	} {
 		if ok := t.Run(scenario.name, scenario.f); !ok {
@@ -227,6 +208,50 @@ func assertThanosRulerVCConfig(cm *v1.ConfigMap) func(*testing.T) {
 
 }
 
+func assertThanosRulerResourcesConfigured(cpu, memory string) func(*testing.T) {
+	return func(t *testing.T) {
+		err := framework.Poll(time.Second, 5*time.Minute, func() error {
+			pods, err := f.KubeClient.CoreV1().Pods(f.UserWorkloadMonitoringNs).List(context.TODO(), metav1.ListOptions{
+				LabelSelector: "thanos-ruler=user-workload",
+				FieldSelector: "status.phase=Running"})
+			if err != nil {
+				t.Fatal(err)
+			}
+			if err != nil {
+				return errors.Wrap(err, "getting Thanos Ruler pods failed")
+			}
+			var (
+				podName       = "thanos-ruler-user-workload-0"
+				containerName = "thanos-ruler"
+			)
+
+			for _, p := range pods.Items {
+				if p.Name == podName {
+					for _, container := range p.Spec.Containers {
+						if container.Name == containerName {
+							containerMemory := container.Resources.Requests[v1.ResourceMemory]
+							actualMemory := containerMemory.String()
+							if actualMemory != memory {
+								return fmt.Errorf("memory requests %s does not match actual %s", memory, actualMemory)
+							}
+							containerCPU := container.Resources.Requests[v1.ResourceCPU]
+							actualCPU := containerCPU.String()
+							if actualCPU != cpu {
+								return fmt.Errorf("CPU requests %s does not match actual %s", cpu, actualCPU)
+							}
+						}
+					}
+
+				}
+			}
+			return nil
+		})
+		if err != nil {
+			t.Fatal(err)
+		}
+	}
+}
+
 func createUserWorkloadAssets(cm *v1.ConfigMap) func(*testing.T) {
 	return func(t *testing.T) {
 		if err := f.OperatorClient.CreateOrUpdateConfigMap(cm); err != nil {
@@ -318,20 +343,23 @@ func assertThanosRulerDeployment(t *testing.T) {
 
 func assertMetricsForMonitoringComponents(t *testing.T) {
 	for service, expected := range map[string]int{
-		"prometheus-operator":      1,
-		"prometheus-user-workload": 2,
-		"thanos-ruler":             2,
+		"prometheus-operator":                     1,
+		"prometheus-user-workload":                2,
+		"thanos-ruler":                            2,
+		"prometheus-user-workload-thanos-sidecar": 2,
 	} {
-		f.ThanosQuerierClient.WaitForQueryReturn(
-			t, 10*time.Minute, fmt.Sprintf(`count(up{service="%s",namespace="openshift-user-workload-monitoring"})`, service),
-			func(i int) error {
-				if i == expected {
-					return nil
-				}
+		t.Run(service, func(t *testing.T) {
+			f.ThanosQuerierClient.WaitForQueryReturn(
+				t, 10*time.Minute, fmt.Sprintf(`count(up{service="%s",namespace="openshift-user-workload-monitoring"} == 1)`, service),
+				func(i int) error {
+					if i == expected {
+						return nil
+					}
 
-				return fmt.Errorf("expected %d targets for service %q but got %d", expected, service, i)
-			},
-		)
+					return fmt.Errorf("expected %d targets to be up but got %d", expected, i)
+				},
+			)
+		})
 	}
 }
 
@@ -671,36 +699,7 @@ func assertUserWorkloadRules(t *testing.T) {
 	f.ThanosQuerierClient.WaitForRulesReturn(
 		t, 10*time.Minute,
 		func(body []byte) error {
-			j, err := gabs.ParseJSON([]byte(body))
-			if err != nil {
-				return err
-			}
-
-			groups, err := j.Path("data.groups").Children()
-			if err != nil {
-				return err
-			}
-
-			for i := 0; i < len(groups); i++ {
-				groupName := groups[i].S("name").Data().(string)
-				if groupName != "example" {
-					continue
-				}
-
-				rules, err := groups[i].Path("rules").Children()
-				if err != nil {
-					return err
-				}
-
-				for j := 0; j < len(rules); j++ {
-					ruleName := rules[j].S("name").Data().(string)
-					if ruleName == "VersionAlert" {
-						return nil
-					}
-				}
-			}
-
-			return errors.New("VersionAlert alert not found")
+			return getThanosRules(body, "example", "VersionAlert")
 		},
 	)
 }
